@@ -541,9 +541,6 @@ sub _require_js {
 
     # QUnit needs some coaxing to work together with RequireJS
     $r .= 'shim: {';
-    $r .= '    "d3": {';
-    $r .= '        "exports": "d3"';
-    $r .= '    },';
     $r .= '    "QUnit": {';
     $r .= '        exports: "QUnit",';
     $r .= '        init: function () {';
